@@ -3,7 +3,7 @@ import os
 import sys
 
 configp = configparser.ConfigParser()
-config_path = str(os.path.dirname(os.path.abspath(__file__))) + '/etc/flake.ini'
+config_path = '/etc/flake.ini'
 configp.read(config_path)
 
 # check if the path is to a valid file
