@@ -2,6 +2,7 @@ import time
 import os
 import json
 import dgl
+import sqlite3
 import networkx as nx
 from collections import defaultdict
 
@@ -182,7 +183,7 @@ class FlurryFlake():
         return id
 
     def save_to_disk(self, db_file):
-        db_conn = sqlite3.connect(db_file)
+        db = sqlite3.connect(db_file)
         start = time.time()
         print("Saving flake to database...")
         cursor = db.cursor()
